<div class="alert alert-danger font-size-sm p-0">
	<table class="table table-borderless table-danger p-0 m-0">
		<tr>
			<td class="align-top" style="width: 5%;"><i class="fas fa-fw fa-2x fa-exclamation-triangle"></i></td>
			<td>Unable to display this attribute as it has attribute tags [<strong>{!! $tags->join('</strong>, <strong>') !!}</strong>].<br>
				You can manage it with an LDIF import.</td>
		</tr>
	</table>
</div>